@@ -2,6 +2,7 @@
 # Triforce Netfirm Toolbox, put into the public domain.
 # Please attribute properly, but only if you want.
 import os
+import sys
 import socket
 import struct
 import time
@@ -231,6 +232,11 @@ class NetDimm:
             # set time limit to 10 minutes.
             self.__set_time_limit(10)
 
+    def set_time_limit(self, limit: int) -> None:
+        with self.connection():
+            # set time limit to specified number of minutes.
+            self.__set_time_limit(limit)
+
     def peek(self, addr: int, type: PeekPokeTypeEnum) -> int:
         with self.connection():
             return self.__host_peek(addr, type)
@@ -280,9 +286,27 @@ class NetDimm:
         # - pre-type3 triforces jumpered to satellite mode.
         try:
             self.sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
-            self.sock.settimeout(1)
-            self.sock.connect((self.ip, 10703))
-            self.sock.settimeout(10)
+
+            # OSX can be a bit difficult to deal with. It appears that their handling of
+            # socket timeouts differs enough from Linux-based systems that we need our
+            # own code path. Specifically, I don't think that it respects timeouts set
+            # after a connection has been made. Without this, OSX-based systems will
+            # time out when trying to reboot and send a game. Note that this behavior
+            # has been seen on some niche Linux-based OSes as well, so I am including an
+            # environment-based escape hatch to enable/disable this just in case. If you
+            # are on OSX the alternate timeout handling will be automatically enabled unless
+            # you set the 'DEFAULT_TIMEOUT_HANDLING' environment variable. If you are not
+            # on OSX and you set 'ALTERNATE_TIMEOUT_HANDLING' the alternate will be enabled
+            # as well.
+            if (sys.platform == 'darwin' or os.environ.get('ALTERNATE_TIMEOUT_HANDLING')) and (not os.environ.get('DEFAULT_TIMEOUT_HANDLING')):
+                self.sock.settimeout(15)
+                self.sock.setblocking(True)
+                self.sock.connect((self.ip, 10703))
+            else:
+                self.sock.settimeout(1)
+                self.sock.connect((self.ip, 10703))
+                self.sock.settimeout(15)
+
         except Exception as e:
             raise NetDimmException("Could not connect to NetDimm") from e
 
